Package: tabula
Title: Analysis and Visualization of Archaeological Count Data
Version: 3.3.2
Authors@R: c(
    person("Nicolas", "Frerebeau", , "nicolas.frerebeau@u-bordeaux-montaigne.fr", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-5759-4944")),
    person("Matthew", "Peeples", , "matthew.peeples@asu.edu", role = "ctb",
           comment = c(ORCID = "0000-0003-4496-623X")),
    person("Ben", "Marwick", , "bmarwick@uw.edu", role = "ctb",
           comment = c(ORCID = "0000-0001-7879-4531")),
    person("Jean-Baptiste", "Fourvel", , "jean-baptiste.fourvel@univ-amu.fr", role = "ctb",
           comment = c(ORCID = "0000-0002-1061-4642")),
    person("Brice", "Lebrun", role = "art",
           comment = c(ORCID = "0000-0001-7503-8685", "Logo designer")),
    person("Université Bordeaux Montaigne", role = "fnd",
           comment = c(ROR = "03pbgwk21")),
    person("CNRS", role = "fnd",
           comment = c(ROR = "02feahw73"))
  )
Maintainer: Nicolas Frerebeau <nicolas.frerebeau@u-bordeaux-montaigne.fr>
Description: An easy way to examine archaeological count data. This
    package provides several tests and measures of diversity:
    heterogeneity and evenness (Brillouin, Shannon, Simpson, etc.),
    richness and rarefaction (Chao1, Chao2, ACE, ICE, etc.), turnover and
    similarity (Brainerd-Robinson, etc.). It allows to easily visualize
    count data and statistical thresholds: rank vs abundance plots,
    heatmaps, Ford (1962) and Bertin (1977) diagrams, etc.
License: GPL (>= 3)
URL: https://codeberg.org/tesselle/tabula,
        https://packages.tesselle.org/tabula/,
        https://tesselle.r-universe.dev/tabula
BugReports: https://codeberg.org/tesselle/tabula/issues
Depends: R (>= 3.5)
Imports: arkhe (>= 1.11.0), graphics, grDevices, khroma (>= 1.16.0),
        methods, stats, utils
Suggests: folio (>= 1.5.0), fontquiver, knitr, markdown, rsvg, svglite,
        tinysnapshot, tinytest
VignetteBuilder: knitr
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
X-schema.org-applicationCategory: Archaeological Science
X-schema.org-isPartOf: https://www.tesselle.org
X-schema.org-keywords: archaeological-science, archaeology,
        data-visualization, diversity-index, r-package
Collate: 'AllClasses.R' 'AllGenerics.R' 'coerce.R' 'data.R'
        'diversity.R' 'diversity_alpha.R' 'diversity_beta.R'
        'diversity_test.R' 'matrigraph.R' 'mutators.R' 'occurrence.R'
        'plot_bertin.R' 'plot_diceleraas.R' 'plot_diversity.R'
        'plot_ford.R' 'plot_heatmap.R' 'plot_matrix.R' 'plot_rank.R'
        'plot_spot.R' 'rarefaction.R' 'reexport.R' 'resample.R'
        'seriograph.R' 'show.R' 'similarity.R' 'statistics.R'
        'subset.R' 'tabula-deprecated.R' 'tabula-internal.R'
        'tabula-package.R' 'validate.R' 'zzz.R'
NeedsCompilation: no
Packaged: 2025-09-04 14:43:21 UTC; nfrerebeau
Author: Nicolas Frerebeau [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-5759-4944>),
  Matthew Peeples [ctb] (ORCID: <https://orcid.org/0000-0003-4496-623X>),
  Ben Marwick [ctb] (ORCID: <https://orcid.org/0000-0001-7879-4531>),
  Jean-Baptiste Fourvel [ctb] (ORCID:
    <https://orcid.org/0000-0002-1061-4642>),
  Brice Lebrun [art] (ORCID: <https://orcid.org/0000-0001-7503-8685>,
    Logo designer),
  Université Bordeaux Montaigne [fnd] (ROR: <https://ror.org/03pbgwk21>),
  CNRS [fnd] (ROR: <https://ror.org/02feahw73>)
Repository: CRAN
Date/Publication: 2025-09-04 15:20:02 UTC
Built: R 4.6.0; ; 2026-04-25 19:53:56 UTC; unix
