# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,DiversityIndex)
S3method(labels,DiversityIndex)
S3method(labels,RarefactionIndex)
S3method(plot,DiversityIndex)
S3method(plot,RarefactionIndex)
S3method(simulate,DiversityIndex)
export(color)
export(index_sorenson)
export(palette_color_continuous)
export(palette_color_discrete)
export(palette_color_picker)
export(resample)
exportMethods(as.data.frame)
exportMethods(bootstrap)
exportMethods(composition)
exportMethods(diversity)
exportMethods(doubleton)
exportMethods(eppm)
exportMethods(evenness)
exportMethods(get_method)
exportMethods(heterogeneity)
exportMethods(index_ace)
exportMethods(index_baxter)
exportMethods(index_berger)
exportMethods(index_binomial)
exportMethods(index_boone)
exportMethods(index_brainerd)
exportMethods(index_bray)
exportMethods(index_brillouin)
exportMethods(index_chao1)
exportMethods(index_chao2)
exportMethods(index_cody)
exportMethods(index_hurlbert)
exportMethods(index_ice)
exportMethods(index_jaccard)
exportMethods(index_margalef)
exportMethods(index_mcintosh)
exportMethods(index_menhinick)
exportMethods(index_morisita)
exportMethods(index_routledge1)
exportMethods(index_routledge2)
exportMethods(index_routledge3)
exportMethods(index_shannon)
exportMethods(index_simpson)
exportMethods(index_sorensen)
exportMethods(index_sorenson)
exportMethods(index_squares)
exportMethods(index_whittaker)
exportMethods(index_wilson)
exportMethods(jackknife)
exportMethods(matrigraph)
exportMethods(observed)
exportMethods(occurrence)
exportMethods(plot)
exportMethods(plot_bertin)
exportMethods(plot_diceleraas)
exportMethods(plot_ford)
exportMethods(plot_heatmap)
exportMethods(plot_rank)
exportMethods(plot_spot)
exportMethods(profiles)
exportMethods(pvi)
exportMethods(rarefaction)
exportMethods(resample)
exportMethods(richness)
exportMethods(seriograph)
exportMethods(she)
exportMethods(similarity)
exportMethods(simulate)
exportMethods(singleton)
exportMethods(test_shannon)
exportMethods(test_simpson)
exportMethods(turnover)
import(arkhe)
importFrom(khroma,color)
importFrom(khroma,palette_color_continuous)
importFrom(khroma,palette_color_discrete)
importFrom(khroma,palette_color_picker)
importFrom(methods,.valueClassTest)
importFrom(methods,as)
importFrom(methods,callGeneric)
importFrom(methods,initialize)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,setClass)
importFrom(methods,setGeneric)
importFrom(methods,setMethod)
importFrom(methods,setOldClass)
importFrom(methods,validObject)
importFrom(stats,as.dist)
importFrom(stats,na.omit)
importFrom(stats,pairwise.table)
importFrom(stats,pt)
importFrom(stats,quantile)
importFrom(stats,rmultinom)
importFrom(stats,sd)
importFrom(utils,combn)
importFrom(utils,head)
importFrom(utils,modifyList)
importFrom(utils,setTxtProgressBar)
importFrom(utils,tail)
importFrom(utils,txtProgressBar)
importMethodsFrom(arkhe,bootstrap)
importMethodsFrom(arkhe,jackknife)
